==> warperia_Blood-Shield-Tracker_2025-11-04_16-54-59.zip: BloodShieldTracker/Locale/ruRU.lua <==
local L = LibStub("AceLocale-3.0"):NewLocale("BloodShieldTracker", "ruRU", false)

if not L then return end

L["Appearance"] = "Внешний вид"
L["Bar Color"] = "Цвет полосы"
L["Bar Depleted Color"] = "Цвет исчерпанной части полосы"
L["BarTexture_OptionDesc"] = "Текстуры используемые полосой" -- Needs review
L["Blizzard"] = true
L["Blood Shield Bar"] = "Полоса Кровавого Щита"
L["BloodShieldBarColor_OptionDesc"] = "Изменят цвет полосы Кровавого Щита"
L["BloodShieldBar_Desc"] = "Полоса Щита Крови показывается всегда, когда он активировен. На полосе отражается максимальное количество урона который он поглотит, после чего аддон считает сколько урона щит ещё поглотит до окончания эффекта. По окончанию эффекта полоса снимается с экрана."
L["Blood Shield bar height"] = "Высота полосы Кровавого Щита"
L["BloodShieldBarTextColor_OptionDesc"] = "Изменить цвет текста полосы Кровавого Щита"
L["Blood Shield bar width"] = "Ширина полосы Кровавого щита"
L["Blood Shield Data"] = "Дата для Кровавого Щита"
L["BloodShieldDepletedBarColor_OptionDesc"] = "Изменяет цвет исчерпанной части полосы Щита. Изчерпанной частью считается незаполненная часть полосы Щита."
L["Blood Shield Max Value"] = "Макс. значение Кровавого Щита"
L["BloodShieldTracker_Desc"] = "BloodShieldTracker это танковский аддон для Рыцарей Смерти(Кровь). Он следит и показывает состояние Кровавого Щита, а также считает приблизительное лечение от Удара Смерти."
L["Blood Shield Usage"] = "Употребление Кровавого Щита"
L["Change the height of the blood shield bar."] = "Изменить высоту полосы Кровавого Щита"
L["Change the height of the estimated healing bar."] = "Изменить высоту полосы приблизительного лечения"
L["Change the width of the blood shield bar."] = "Изменить ширину полосы Кровавого щита"
L["Change the width of the estimated healing bar."] = "Изменить ширину полосы приблизительного лечения"
L["Colors"] = "Цвета"
L["Colors for Minimum Heal"] = "Цвета для минимального лечения"
L["Colors for Optimal Heal"] = "Цвета для оптимального лечения"
L["Config Mode"] = "Настроить"
L["Could not determine talents."] = "Ошибка при определении талантов."
L["Current and Maximum"] = "Текущее и максимум"
L["Dimensions"] = "Размеры"
L["Enabled"] = "Включен"
L["Enable the Blood Shield Bar."] = "Включить показ полосы Кровавого Щита"
L["Enable the Estimated Healing Bar."] = "Включить показ полосы приблизительного лечения"
L["EstHealBarMinBackgroundColor_OptionDesc"] = "Изменяет цвет фона полосы приблизительного лечения для миню лечения от Удара Смерти."
L["EstHealBarMinColor_OptionDesc"] = "Изменить цвет полосы минимального лечения от Удара смерти на полосе приблизительного лечения"
L["EstHealBarMinTextColor_OptionDesc"] = "Изменить цвет текста минимального лечения от Удара смерти на полосе приблизительного лечения"
L["EstHealBarOptColor_OptionDesc"] = "Изменить цвет полосы оптимального лечения от Удара смерти на полосе приблизительного лечения"
L["EstHealBarOptTextColor_OptionDesc"] = "Изменить цвет текста оптимального лечения от Удара смерти на полосе приблизительного лечения"
L["Estimated Healing Bar"] = "Полоса приблизительного лечения"
L["EstimatedHealingBar_Desc"] = "Полоса приблизительного лечения показывает калькулированное аддоном количество лечения от Удара Смерти на момент использования. Если лечение от Удара Смерти будет минимальным (т.е. 10% от макс. здоровья) то полоса отображается по умолчанию красным цветом. Если же лечение превышает минимум (оптимальное лечение) то полоса по умолчанию зелёного цвета. По этим цветам легче определить, когда лучше использовать Удар Смерти для лечения. Эти цвета могут быть изменены в настройках.  "
L["Estimated Healing bar height"] = "Высота полосы приблизительного лечения"
L["Estimated Healing bar width"] = "Ширина полосы приблизительного лечения"
L["Fight Duration:"] = "Длительность боя"
L["Font"] = "Шрифт"
L["Font size"] = "Размер шрифта"
L["Font size for the bars."] = "Размер шрифта на полосах"
L["Font to use."] = "Шрифт для использования"
L["Font to use for this panel."] = "Шрифт для использования на этой панели"
L["Full"] = "Полный"
L["General Options"] = "Общие настройки"
L["HealBarText"] = "Прим. лечение"
L["Height"] = "Высота"
L["HideOOC_OptionDesc"] = "Спрятять полосу лечения когда вне боя"
L["Hide out of combat"] = "Спрятать когда вне боя"
L["Left"] = "Лево"
L["Lock bar"] = "Закрепить полосу на месте"
L["Lock damage bar"] = "Закрепить полосу урона"
L["Lock estimated healing bar"] = "Закрепить полосу лечения"
L["Lock shield bar"] = "Закрепить полосу щита"
L["Lock status bar"] = "Закрепить полосу статуса"
L["Lock the damage bar from moving."] = "Закрепляет полосу урона на место"
L["Lock the estimated healing bar from moving."] = "Закрепляет полосу приблизительного лечения на место"
L["Lock the shield bar from moving."] = "Закрепляет полосу щита на место"
L["Lock the status bar from moving."] = "Закрепляет полосу статуса на место"
L["Minimap Button"] = "Кнопка на мини-карте"
L["Minimum Bar Background Color"] = "Цвет фона полосы минимального лечения"
L["Minimum Bar Color"] = "Цвет полосы минимального лечения"
L["Minimum Text Color"] = "Цвет текста минимального лечения"
L["Min - Max / Avg:"] = "Мин - Макс / Сред:"
L["Number of Minimum Shields:"] = "Минимальный номер щитов"
L["Only Current"] = "Только текущее"
L["Only Maximum"] = "Только максимум"
L["Only Percent"] = "Только проценты"
L["Optimal Bar Color"] = "Цвет полосы оптимального лечения"
L["Optimal Text Color"] = "Цвет текста оптимального лечения"
L["Position"] = "Позиция"
L["Right"] = "Право"
L["Scale"] = "Шкала"
L["ScaleDesc"] = "Настроить сопостовимость полос."
L["Shields Total/Refreshed/Removed:"] = "Щиты Всего/Обновлено/Снято"
L["Shift + Left-Click to reset."] = "Shift + ЛКМ для сброса"
L["ShowBar"] = "Показывать фон"
L["ShowBarDesc"] = "Отключите эту опцию, если хотите чтобы на полосах показывался только текст без фона и границ. "
L["ShowBorder"] = "Показывать границы"
L["ShowBorderDesc"] = "Показывать границы вокруг полосы"
L["Show Text"] = "Показать текст"
L["Show Time"] = "Показать время"
L["Sound"] = "Звук"
L["StatusBarTexture"] = "Текстура полосы статуса"
L["Text Color"] = "Цвет текста"
L["Text Format"] = "Формат текста"
L["Texture"] = "Текстура"
L["Time Remaining"] = "Оставшееся время"
L["Toggle config mode"] = "Настроить места полос на экране"
L["Toggles the display of informational messages"] = "Включает показ информационных сообщений"
L["Toggle the minimap button"] = "Отображать кнопку на краю мини-карты"
L["Usage Min - Max / Avg:"] = "Употребление Мин - Макс / Сред:"
L["Verbose"] = "Сообщения на экране"
L["Width"] = "Ширина"

==> warperia_Blood-Shield-Tracker_2025-12-12_15-56-07.zip: BloodShieldTracker/Locale/ruRU.lua <==
local L = LibStub("AceLocale-3.0"):NewLocale("BloodShieldTracker", "ruRU", false)

if not L then return end

L["Appearance"] = "Внешний вид"
L["Bar Color"] = "Цвет полосы"
L["Bar Depleted Color"] = "Цвет исчерпанной части полосы"
L["BarTexture_OptionDesc"] = "Текстуры используемые полосой"
L["Blizzard"] = true
L["Blood Shield Bar"] = "Полоса Кровавого Щита"
L["Blood Shield bar height"] = "Высота полосы Кровавого Щита"
L["Blood Shield bar width"] = "Ширина полосы Кровавого щита"
L["Blood Shield Data"] = "Дата для Кровавого Щита"
L["Blood Shield Max Value"] = "Макс. значение Кровавого Щита"
L["Blood Shield Usage"] = "Употребление Кровавого Щита"
L["BloodShieldBar_Desc"] = "Полоса Щита Крови показывается всегда, когда он активировен. На полосе отражается максимальное количество урона который он поглотит, после чего аддон считает сколько урона щит ещё поглотит до окончания эффекта. По окончанию эффекта полоса снимается с экрана."
L["BloodShieldBarColor_OptionDesc"] = "Изменят цвет полосы Кровавого Щита"
L["BloodShieldBarTextColor_OptionDesc"] = "Изменить цвет текста полосы Кровавого Щита"
L["BloodShieldDepletedBarColor_OptionDesc"] = "Изменяет цвет исчерпанной части полосы Щита. Изчерпанной частью считается незаполненная часть полосы Щита."
L["BloodShieldTracker_Desc"] = "BloodShieldTracker это танковский аддон для Рыцарей Смерти(Кровь). Он следит и показывает состояние Кровавого Щита, а также считает приблизительное лечение от Удара Смерти."
L["Change the height of the blood shield bar."] = "Изменить высоту полосы Кровавого Щита"
L["Change the height of the estimated healing bar."] = "Изменить высоту полосы приблизительного лечения"
L["Change the width of the blood shield bar."] = "Изменить ширину полосы Кровавого щита"
L["Change the width of the estimated healing bar."] = "Изменить ширину полосы приблизительного лечения"
L["Colors"] = "Цвета"
L["Colors for Minimum Heal"] = "Цвета для минимального лечения"
L["Colors for Optimal Heal"] = "Цвета для оптимального лечения"
L["Config Mode"] = "Настроить"
L["Could not determine talents."] = "Ошибка при определении талантов."
L["Current and Maximum"] = "Текущее и максимум"
L["Dimensions"] = "Размеры"
L["Enable the Blood Shield Bar."] = "Включить показ полосы Кровавого Щита"
L["Enable the Estimated Healing Bar."] = "Включить показ полосы приблизительного лечения"
L["Enabled"] = "Включен"
L["EstHealBarMinBackgroundColor_OptionDesc"] = "Изменяет цвет фона полосы приблизительного лечения для миню лечения от Удара Смерти."
L["EstHealBarMinColor_OptionDesc"] = "Изменить цвет полосы минимального лечения от Удара смерти на полосе приблизительного лечения"
L["EstHealBarMinTextColor_OptionDesc"] = "Изменить цвет текста минимального лечения от Удара смерти на полосе приблизительного лечения"
L["EstHealBarOptColor_OptionDesc"] = "Изменить цвет полосы оптимального лечения от Удара смерти на полосе приблизительного лечения"
L["EstHealBarOptTextColor_OptionDesc"] = "Изменить цвет текста оптимального лечения от Удара смерти на полосе приблизительного лечения"
L["Estimated Healing Bar"] = "Полоса приблизительного лечения"
L["Estimated Healing bar height"] = "Высота полосы приблизительного лечения"
L["Estimated Healing bar width"] = "Ширина полосы приблизительного лечения"
L["EstimatedHealingBar_Desc"] = "Полоса приблизительного лечения показывает калькулированное аддоном количество лечения от Удара Смерти на момент использования. Если лечение от Удара Смерти будет минимальным (т.е. 10% от макс. здоровья) то полоса отображается по умолчанию красным цветом. Если же лечение превышает минимум (оптимальное лечение) то полоса по умолчанию зелёного цвета. По этим цветам легче определить, когда лучше использовать Удар Смерти для лечения. Эти цвета могут быть изменены в настройках.  "
L["Fight Duration:"] = "Длительность боя"
L["Font"] = "Шрифт"
L["Font size"] = "Размер шрифта"
L["Font size for the bars."] = "Размер шрифта на полосах"
L["Font to use for this panel."] = "Шрифт для использования на этой панели"
L["Font to use."] = "Шрифт для использования"
L["Full"] = "Полный"
L["General Options"] = "Общие настройки"
L["HealBarText"] = "Прим. лечение"
L["Height"] = "Высота"
L["Hide out of combat"] = "Спрятать когда вне боя"
L["HideOOC_OptionDesc"] = "Спрятять полосу лечения когда вне боя"
L["Left"] = "Лево"
L["Lock bar"] = "Закрепить полосу на месте"
L["Lock damage bar"] = "Закрепить полосу урона"
L["Lock estimated healing bar"] = "Закрепить полосу лечения"
L["Lock shield bar"] = "Закрепить полосу щита"
L["Lock status bar"] = "Закрепить полосу статуса"
L["Lock the damage bar from moving."] = "Закрепляет полосу урона на место"
L["Lock the estimated healing bar from moving."] = "Закрепляет полосу приблизительного лечения на место"
L["Lock the shield bar from moving."] = "Закрепляет полосу щита на место"
L["Lock the status bar from moving."] = "Закрепляет полосу статуса на место"
L["Min - Max / Avg:"] = "Мин - Макс / Сред:"
L["Minimap Button"] = "Кнопка на мини-карте"
L["Minimum Bar Background Color"] = "Цвет фона полосы минимального лечения"
L["Minimum Bar Color"] = "Цвет полосы минимального лечения"
L["Minimum Text Color"] = "Цвет текста минимального лечения"
L["Number of Minimum Shields:"] = "Минимальный номер щитов"
L["Only Current"] = "Только текущее"
L["Only Maximum"] = "Только максимум"
L["Only Percent"] = "Только проценты"
L["Optimal Bar Color"] = "Цвет полосы оптимального лечения"
L["Optimal Text Color"] = "Цвет текста оптимального лечения"
L["Position"] = "Позиция"
L["Right"] = "Право"
L["Scale"] = "Шкала"
L["ScaleDesc"] = "Настроить сопостовимость полос."
L["Shields Total/Refreshed/Removed:"] = "Щиты Всего/Обновлено/Снято"
L["Shift + Left-Click to reset."] = "Shift + ЛКМ для сброса"
L["Show Text"] = "Показать текст"
L["Show Time"] = "Показать время"
L["ShowBar"] = "Показывать фон"
L["ShowBarDesc"] = "Отключите эту опцию, если хотите чтобы на полосах показывался только текст без фона и границ. "
L["ShowBorder"] = "Показывать границы"
L["ShowBorderDesc"] = "Показывать границы вокруг полосы"
L["Sound"] = "Звук"
L["StatusBarTexture"] = "Текстура полосы статуса"
L["Text Color"] = "Цвет текста"
L["Text Format"] = "Формат текста"
L["Texture"] = "Текстура"
L["Time Remaining"] = "Оставшееся время"
L["Toggle config mode"] = "Настроить места полос на экране"
L["Toggle the minimap button"] = "Отображать кнопку на краю мини-карты"
L["Toggles the display of informational messages"] = "Включает показ информационных сообщений"
L["Usage Min - Max / Avg:"] = "Употребление Мин - Макс / Сред:"
L["Verbose"] = "Сообщения на экране"
L["Width"] = "Ширина"
